==> haskell-text-metrics-0.3.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-metrics
version:              0.3.1
visibility:           public
id:                   text-metrics-0.3.1-2aaRfVa70B643ht2XnGb3g
key:                  text-metrics-0.3.1-2aaRfVa70B643ht2XnGb3g
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  ec40a572bac024cce2fb133be838c020
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.0.1/site-local/text-metrics-0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/text-metrics-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/text-metrics-0.3.1
hs-libraries:         HStext-metrics-0.3.1-2aaRfVa70B643ht2XnGb3g
depends:
    base-4.15.0.0 containers-0.6.4.1 text-1.2.4.1
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-metrics-0.3.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-metrics
version:              0.3.1
visibility:           public
id:                   text-metrics-0.3.1-JSa2NtWqEAWJ9a890VVxb8
key:                  text-metrics-0.3.1-JSa2NtWqEAWJ9a890VVxb8
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  9005372ce8005f1910d91e6fc19c867b
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.0.1/site-local/text-metrics-0.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/text-metrics-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/text-metrics-0.3.1
hs-libraries:         HStext-metrics-0.3.1-JSa2NtWqEAWJ9a890VVxb8
depends:
    base-4.15.0.0 containers-0.6.4.1 text-1.2.4.1
    vector-0.12.3.0-GI0lTgAWws2EpJyQa7KDn5

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
